## Radiance look and feel

Radiance provides a powerful and flexible set of APIs that can be used to skin Swing applications to address the most demanding, modern design requirements. It comes with built-in support for all core Swing components, and a comprehensive API set for consistent rendering of third-party / application components.

[![Maven Central](https://maven-badges.herokuapp.com/maven-central/org.pushing-pixels/radiance-theming/badge.svg)](https://maven-badges.herokuapp.com/maven-central/org.pushing-pixels/radiance-theming) `radiance-theming` for build instructions of the latest stable release.

### Overview

* [Getting started](getting-started.md)
* [How to add Radiance to your project](add-to-your-project.md)
* [Known issues](known-issues.md)

### Working with Radiance

* [API surface](api.md)
* [Animations](animations.md)
* [Renderers](renderers.md)
* [Plugins](plugin.md)
* [Title pane](titlepane.md)
* [Fonts](fonts.md)
* [Text highlights](texthighlight.md)
* [Themed states](themed-states.md)
* [Extras](extras.md)
* [Internals](internals.md)

### Skins

* [Overview](skins/overview.md)
* [Component states](skins/componentstates.md)
* [Color schemes](skins/colorschemes.md)
* [Color scheme association kinds](skins/colorschemeassociationkinds.md)
* [Color scheme file format](skins/colorschemes-fileformat.md)
* [Color scheme bundles](skins/colorschemebundles.md)
* [Color scheme extras](skins/colorschemes-extras.md)
* [Light skins](skins/toneddown.md)
* [Dark skins](skins/dark.md)

### Painters

* [Overview](painters/overview.md)
* [Fill painters](painters/fill.md)
* [Border painters](painters/border.md)
* [Highlight painters](painters/highlight.md)
* [Decoration painters](painters/decoration.md)
* [Overlay painters](painters/overlay.md)
* [Custom skinning](painters/custom-skinning.md)

### Code samples

* [Main Radiance demo](https://github.com/kirill-grouchnikov/radiance/tree/sunshine/demos/theming-demo/src/main/java/org/pushingpixels/radiance/demo/theming/main)
* [Additional sample apps](https://github.com/kirill-grouchnikov/radiance/tree/sunshine/demos/theming-apps/src/main/java/org/pushingpixels/radiance/demo/themingapps)
* [Cookbook walkthrough](cookbook/cookbook.md)

### Have a question?

* [File a bug](https://github.com/kirill-grouchnikov/radiance/issues)
* [Get in touch](http://www.pushing-pixels.org/about-kirill)
